==> auth_buttons-2.0.0.tar.gz: lib/src/utils/auth_icons.dart <==
// Copyright (c) 2021 Talat El Beick. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

class AuthIcons {
  static const List<String> google = <String>[
    'packages/auth_buttons/images/default/google.svg',
    'packages/auth_buttons/images/outlined/google.svg',
    'packages/auth_buttons/images/secondary/google.svg',
  ];
  static const List<String> facebook = <String>[
    'packages/auth_buttons/images/default/facebook.svg',
    'packages/auth_buttons/images/outlined/facebook.svg',
    'packages/auth_buttons/images/secondary/facebook.svg',
  ];
  static const List<String> facebookWhite = <String>[
    'packages/auth_buttons/images/default/facebook_white.svg',
    'packages/auth_buttons/images/outlined/facebook_white.svg',
  ];

  static const List<String> apple = <String>[
    'packages/auth_buttons/images/default/apple.svg',
    'packages/auth_buttons/images/outlined/apple.svg',
    'packages/auth_buttons/images/secondary/apple.svg',
  ];
  static const List<String> appleWhite = <String>[
    'packages/auth_buttons/images/default/apple_white.svg',
    'packages/auth_buttons/images/outlined/apple_white.svg',
  ];
  static const List<String> twitter = <String>[
    'packages/auth_buttons/images/default/twitter.svg',
    'packages/auth_buttons/images/outlined/twitter.svg',
    'packages/auth_buttons/images/secondary/twitter.svg',
  ];
  static const List<String> twitterWhite = <String>[
    'packages/auth_buttons/images/default/twitter_white.svg',
    'packages/auth_buttons/images/outlined/twitter_white.svg',
  ];
  static const List<String> github = [
    'packages/auth_buttons/images/default/github_black.svg',
    'packages/auth_buttons/images/outlined/github.svg',
    'packages/auth_buttons/images/secondary/github.svg',
  ];
  static const List<String> githubWhite = [
    'packages/auth_buttons/images/default/github_white.svg',
    'packages/auth_buttons/images/outlined/github_white.svg',
  ];
  static const List<String> microsoft = <String>[
    'packages/auth_buttons/images/default/microsoft.svg',
    'packages/auth_buttons/images/outlined/microsoft.svg',
    'packages/auth_buttons/images/secondary/microsoft.svg',
  ];

  static const List<String> email = <String>[
    'packages/auth_buttons/images/default/email.svg',
    'packages/auth_buttons/images/outlined/email.svg',
    'packages/auth_buttons/images/secondary/email.svg',
  ];
  static const List<String> emailWhite = <String>[
    'packages/auth_buttons/images/default/email_white.svg',
    'packages/auth_buttons/images/outlined/email_white.svg',
    'packages/auth_buttons/images/secondary/email_white.svg',
  ];

  static const List<String> huawei = <String>[
    'packages/auth_buttons/images/default/huawei.svg',
    'packages/auth_buttons/images/outlined/huawei.svg',
    'packages/auth_buttons/images/secondary/huawei.svg',
  ];
  static const List<String> huaweiWhite = <String>[
    'packages/auth_buttons/images/default/huawei_white.svg',
    'packages/auth_buttons/images/outlined/huawei_white.svg',
  ];
}

==> auth_buttons-3.0.2.tar.gz: lib/src/utils/auth_icons.dart <==
// Copyright (c) 2021 Talat El Beick. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

class AuthIcons {
  static const List<String> google = <String>[
    'packages/auth_buttons/images/default/google.svg',
    'packages/auth_buttons/images/outlined/google.svg',
    'packages/auth_buttons/images/secondary/google.svg',
  ];

  static const List<String> facebook = <String>[
    'packages/auth_buttons/images/default/facebook.svg',
    'packages/auth_buttons/images/outlined/facebook.svg',
    'packages/auth_buttons/images/secondary/facebook.svg',
  ];

  static const List<String> apple = <String>[
    'packages/auth_buttons/images/default/apple.svg',
    'packages/auth_buttons/images/outlined/apple.svg',
    'packages/auth_buttons/images/secondary/apple.svg',
  ];

  static const List<String> twitter = <String>[
    'packages/auth_buttons/images/default/twitter.svg',
    'packages/auth_buttons/images/outlined/twitter.svg',
    'packages/auth_buttons/images/secondary/twitter.svg',
  ];

  static const List<String> github = <String>[
    'packages/auth_buttons/images/default/github_black.svg',
    'packages/auth_buttons/images/outlined/github.svg',
    'packages/auth_buttons/images/secondary/github.svg',
  ];

  static const List<String> microsoft = <String>[
    'packages/auth_buttons/images/default/microsoft.svg',
    'packages/auth_buttons/images/outlined/microsoft.svg',
    'packages/auth_buttons/images/secondary/microsoft.svg',
  ];

  static const List<String> email = <String>[
    'packages/auth_buttons/images/default/email.svg',
    'packages/auth_buttons/images/outlined/email.svg',
    'packages/auth_buttons/images/secondary/email.svg',
  ];

  static const List<String> huawei = <String>[
    'packages/auth_buttons/images/default/huawei.svg',
    'packages/auth_buttons/images/outlined/huawei.svg',
    'packages/auth_buttons/images/secondary/huawei.svg',
  ];
}
